@@ -4,17 +4,17 @@
 modname = 'postgis'
 distname = 'cubicweb-%s' % modname
 
-numversion = (0, 7, 1)
+numversion = (0, 8, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 description = 'Test for postgis'
-web = 'https://www.cubicweb.org/project/%s' % distname
+web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.26.19',
+    'cubicweb': ">= 3.26.19, < 3.37.0",
 }
 __recommends__ = {}
 
